@@ -1,87 +1,91 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import re
-import six
 import unicodedata
+from typing import Any, Optional
 
 from normality.constants import UNICODE_CATEGORIES, CONTROL_CODES, WS
+from normality.util import Categories, is_text
 
-COLLAPSE_RE = re.compile(r'\s+', re.U)
-BOM_RE = re.compile('^\ufeff', re.U)
-UNSAFE_RE = re.compile(r'^\ufeff|[\x00-\x08\x0b-\x0c\x0e-\x1f\x7f\x80-\x9f]')
+COLLAPSE_RE = re.compile(r"\s+", re.U)
+BOM_RE = re.compile("^\ufeff", re.U)
+UNSAFE_RE = re.compile(r"^\ufeff|[\x00-\x08\x0b-\x0c\x0e-\x1f\x7f\x80-\x9f]")
 QUOTES_RE = re.compile(r'^["\'](.*)["\']$')
 
 
-def decompose_nfkd(text):
+def decompose_nfkd(text: Any) -> Optional[str]:
     """Perform unicode compatibility decomposition.
 
     This will replace some non-standard value representations in unicode and
     normalise them, while also separating characters and their diacritics into
     two separate codepoints.
     """
-    if is_text(text):
-        return unicodedata.normalize('NFKD', text)
+    if not is_text(text):
+        return None
+    return unicodedata.normalize("NFKD", text)
 
 
-def compose_nfc(text):
+def compose_nfc(text: Any) -> Optional[str]:
     """Perform unicode composition."""
-    if is_text(text):
-        return unicodedata.normalize('NFC', text)
+    if not is_text(text):
+        return None
+    return unicodedata.normalize("NFC", text)
 
 
-def compose_nfkc(text):
+def compose_nfkc(text: Any) -> Optional[str]:
     """Perform unicode composition."""
-    if is_text(text):
-        return unicodedata.normalize('NFKC', text)
+    if not is_text(text):
+        return None
+    return unicodedata.normalize("NFKC", text)
 
 
-def strip_quotes(text):
+def strip_quotes(text: Any) -> Optional[str]:
     """Remove double or single quotes surrounding a string."""
-    if is_text(text):
-        return QUOTES_RE.sub('\\1', text)
+    if not is_text(text):
+        return None
+    return QUOTES_RE.sub("\\1", text)
 
 
-def category_replace(text, replacements=UNICODE_CATEGORIES):
+def category_replace(
+    text: Any, replacements: Categories = UNICODE_CATEGORIES
+) -> Optional[str]:
     """Remove characters from a string based on unicode classes.
 
     This is a method for removing non-text characters (such as punctuation,
     whitespace, marks and diacritics) from a piece of text by class, rather
     than specifying them individually.
     """
+    text = decompose_nfkd(text)
     if not is_text(text):
         return None
     characters = []
-    for character in decompose_nfkd(text):
+    for character in text:
         cat = unicodedata.category(character)
         replacement = replacements.get(cat, character)
         if replacement is not None:
             characters.append(replacement)
-    return u''.join(characters)
+    return u"".join(characters)
 
 
-def remove_control_chars(text):
+def remove_control_chars(text: Any) -> Optional[str]:
     """Remove just the control codes from a piece of text."""
     return category_replace(text, replacements=CONTROL_CODES)
 
 
-def remove_unsafe_chars(text):
+def remove_unsafe_chars(text: Any) -> Optional[str]:
     """Remove unsafe unicode characters from a piece of text."""
-    if is_text(text):
-        return UNSAFE_RE.sub('', text)
+    if not is_text(text):
+        return None
+    return UNSAFE_RE.sub("", text)
 
 
-def remove_byte_order_mark(text):
+def remove_byte_order_mark(text: Any) -> Optional[str]:
     """Remove a BOM from the beginning of the text."""
-    if is_text(text):
-        return BOM_RE.sub('', text)
+    if not is_text(text):
+        return None
+    return BOM_RE.sub("", text)
 
 
-def collapse_spaces(text):
+def collapse_spaces(text: Any) -> Optional[str]:
     """Remove newlines, tabs and multiple spaces with single spaces."""
-    if is_text(text):
-        return COLLAPSE_RE.sub(WS, text).strip(WS)
-
-
-def is_text(data):
-    return isinstance(data, six.text_type)
+    if not is_text(text):
+        return None
+    return COLLAPSE_RE.sub(WS, text).strip(WS)
