@@ -27,6 +27,11 @@ def normalize_encoding(encoding: str, default: Encoding = DEFAULT_ENCODING) -> s
         "normalize_encoding is now deprecated. Use tidy_encoding instead",
         DeprecationWarning,
     )
+    return tidy_encoding(encoding, default)
+
+
+def tidy_encoding(encoding: str, default: Encoding = DEFAULT_ENCODING) -> str:
+    """Normalize the encoding name, replace ASCII w/ UTF-8."""
     if encoding is None:
         return default
     encoding = encoding.lower().strip()
@@ -41,11 +46,6 @@ def normalize_encoding(encoding: str, default: Encoding = DEFAULT_ENCODING) -> s
     return default
 
 
-def tidy_encoding(encoding: str, default: Encoding = DEFAULT_ENCODING) -> str:
-    """Normalize the encoding name, replace ASCII w/ UTF-8."""
-    return normalize_encoding(encoding, default)
-
-
 def normalize_result(
     result: "_IntermediateResultType", default: Encoding, threshold: float = 0.2
 ) -> Encoding:
@@ -100,7 +100,6 @@ def predict_encoding(text: bytes, default: Encoding = DEFAULT_ENCODING) -> Encod
     guess the appropriate encoding of the text.
     """
     result = from_bytes(text, explain=False)
-
     return tidy_result(result, default=default)
 
 
